@@ -21,5 +21,15 @@ Globals - module providing global Simulation object and the global
 stepping - a simple interactive debugger
 
 """
-__version__ = '2.2'
-__SimPyVersion__ = __version__
+__version__ = '2.3.1'
+
+
+def test():
+    import os.path
+    try:
+        import pytest
+    except ImportError:
+        print('You need pytest and mock to run the tests. '
+              'Try "pip install pytest mock".')
+    else:
+        pytest.main([os.path.dirname(__file__)])
